#
# spec file for package nst
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define commit 3df8353

Name:           nst
Version:        0.2
Release:        2.1
Summary:        C++ port of suckless.org st (simple-terminal) emulator
License:        MIT
Group:          System/X11/Terminals
URL:            https://github.com/gerstner-hub/nst
Source0:        nst-1.0+git%{commit}.tar.xz
Source1:        nst_config.cxx
Source2:        nst_config.hxx
Patch0:         usr_etc_lookup.patch

BuildRequires:  asciidoc
BuildRequires:  gcc-c++
BuildRequires:  libXft-devel
BuildRequires:  libcosmos-devel
BuildRequires:  libxpp-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  scons
BuildRequires:  tclap

%description
The not (so) simple terminal emulator. It is a C++ port of st, the simple
terminal emulator for X that sucks less. Apart from a modernized code base
nst offers builtin scrollback buffer support, enhanced smart selection
features and the possibility to process the terminal buffer history in
external tools for searching.

%prep
%setup -q -n nst-1.0+git%{commit}
%autopatch -p1
# copy compile time configuration from package sources into source tree
cp %{SOURCE1} src
cp %{SOURCE2} src

%build
scons libtype=shared use-system-pkgs=1

%install
scons install instroot=%{buildroot}/usr use-system-pkgs=1

%files
%license LICENSE
%doc README.md
%{_bindir}/nst*
%{_distconfdir}/nst.conf
%{_datadir}/applications/%{name}.desktop
%{_datadir}/terminfo/n/nst*
%{_mandir}/man1/nst*
%{_mandir}/man5/nst*

%changelog
* Thu Mar 14 2024 matthias.gerstner@suse.com
- Update to version 1.0+git3df8353:
  * README.md: document configuration file support
  * nst: make external command to receive terminal buffer configurable
  * doc: update and complement man pages
  * nst: support extra configuration file specified in environment variable
  * Cmdline: support additional config file specification
  * SConstruct files: fix flake8 findings
  * XEventHandler: support ConfigFile override of KbdShortcuts
  * themes: gruvbox: fix invalid reverse cursor color index
  * nst: support color configuration via ConfigFile
  * Screen: asText(): don't add newlines for wrapped lines
  * themes: make theme configurable via ConfigFile
  * global: use runtime defined Theme structure
  * Theme: use std::vector for extended colors
  * Selection: make SEL_URI_SCHEMES configurable via ConfigFile
  * Term: make HISTORY_LEN configurable via ConfigFile
  * WindowSystem: make HIDE_MOUSE_CURSOR configurable via ConfigFile
  * Term: make KEEP_SCROLL_POSITION configurable via ConfigFile
  * WindowSystem: support configuration of COLS and ROWS via ConfigFile
  * WindowSystem: support configuration of CURSORSHAPE via ConfigFile
  * WindowSystem: make CURSOR_THICKNESS configurable via ConfigFile
  * nst: make BLINK_TIMEOUT configurable via ConfigFile
  * Selection: make SEL_LINE_SNAP_KEEP_NEWLINE configurable via ConfigFile
  * XEventHandler: support configuring SEL_CLEAR via ConfigFile
  * ConfigFile: support obtaining boolean config values
  * WindowSystem: support configuration of BORDER_PX via ConfigFile
  * TTY: bad SIGCHILD handling logic
  * Selection: support configuring WORD_DELIMITERS via configuration file
  * ConfigFile: support getting wstring config values
  * ConfigFile: support unicode strings and proper string quoting style
  * feature: add support for a simple configuration file
  * README.md: reflect latest development efforts
  * README.md: fix some typos
  * CSIEscape: fix error message in parseColor()
  * nst-msg: support operating on specific instance by passing PID
- add usr_etc_lookup.patch: lookup config in /usr/etc as well.
* Tue Feb 20 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- initial version of the package
